@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2020, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2.0, as published by the
@@ -29,8 +29,8 @@
 
 package com.mysql.cj.result;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
@@ -39,7 +39,7 @@ import java.time.LocalDate;
 import java.util.TimeZone;
 import java.util.concurrent.Callable;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.mysql.cj.MysqlType;
 import com.mysql.cj.conf.DefaultPropertySet;
@@ -55,7 +55,6 @@ import com.mysql.cj.protocol.InternalTimestamp;
  * Tests for JDBC {@link java.sql.Date} creation.
  */
 public class SqlDateValueFactoryTest extends CommonAsserts {
-
     PropertySet pset = new DefaultPropertySet();
     SqlDateValueFactory vf = new SqlDateValueFactory(this.pset, null, TimeZone.getDefault());
 
@@ -75,7 +74,7 @@ public class SqlDateValueFactoryTest extends CommonAsserts {
         assertEquals("1970-01-01", this.vf.createFromTime(new InternalTime(12, 20, 02, 4, 9)).toString());
         assertEquals("1970-01-01", this.vf.createFromTime(new InternalTime(1, 1, 1, 1, 9)).toString());
         assertEquals("1970-01-01", this.vf.createFromTime(new InternalTime(-1, 1, 1, 1, 9)).toString());
-        assertEquals("1970-01-03", this.vf.createFromTime(new InternalTime(48, 1, 1, 1, 9)).toString());
+        assertEquals("1970-01-01", this.vf.createFromTime(new InternalTime(48, 1, 1, 1, 9)).toString());
     }
 
     @Test
