@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2021, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2.0, as published by the
@@ -29,8 +29,8 @@
 
 package com.mysql.cj.result;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
@@ -39,7 +39,7 @@ import java.time.LocalTime;
 import java.util.TimeZone;
 import java.util.concurrent.Callable;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.mysql.cj.MysqlType;
 import com.mysql.cj.conf.DefaultPropertySet;
@@ -55,7 +55,6 @@ import com.mysql.cj.protocol.InternalTimestamp;
  * Tests for JDBC {@link java.sql.Time} creation.
  */
 public class SqlTimeValueFactoryTest extends CommonAsserts {
-
     PropertySet pset = new DefaultPropertySet();
     SqlTimeValueFactory vf = new SqlTimeValueFactory(this.pset, null, TimeZone.getDefault());
 
@@ -66,13 +65,8 @@ public class SqlTimeValueFactoryTest extends CommonAsserts {
 
     @Test
     public void testCreateFromDate() {
-        assertThrows(DataConversionException.class, "Unsupported conversion from DATE to java.sql.Time", new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-                SqlTimeValueFactoryTest.this.vf.createFromDate(new InternalDate(2015, 5, 1));
-                return null;
-            }
-        });
+        assertEquals(Time.valueOf(LocalTime.of(0, 0)), this.vf.createFromDate(new InternalDate(2015, 5, 1)));
+        assertEquals(Time.valueOf(LocalTime.of(0, 0)).toString(), this.vf.createFromDate(new InternalDate(2015, 5, 1)).toString());
     }
 
     @Test
@@ -82,7 +76,7 @@ public class SqlTimeValueFactoryTest extends CommonAsserts {
         assertEquals(Time.valueOf(LocalTime.of(1, 1, 1, 1)), this.vf.createFromTime(new InternalTime(1, 1, 1, 1, 9)));
 
         assertThrows(DataReadException.class,
-                "The value '-1:0:0' is an invalid TIME value. JDBC Time objects represent a wall-clock time and not a duration as MySQL treats them. If you are treating this type as a duration, consider retrieving this value as a string and dealing with it according to your requirements.",
+                "The value '-1:00:00' is an invalid TIME value. JDBC Time objects represent a wall-clock time and not a duration as MySQL treats them. If you are treating this type as a duration, consider retrieving this value as a string and dealing with it according to your requirements.",
                 new Callable<Void>() {
                     @Override
                     public Void call() throws Exception {
@@ -92,7 +86,7 @@ public class SqlTimeValueFactoryTest extends CommonAsserts {
                 });
 
         assertThrows(DataReadException.class,
-                "The value '44:0:0' is an invalid TIME value. JDBC Time objects represent a wall-clock time and not a duration as MySQL treats them. If you are treating this type as a duration, consider retrieving this value as a string and dealing with it according to your requirements.",
+                "The value '44:00:00' is an invalid TIME value. JDBC Time objects represent a wall-clock time and not a duration as MySQL treats them. If you are treating this type as a duration, consider retrieving this value as a string and dealing with it according to your requirements.",
                 new Callable<Void>() {
                     @Override
                     public Void call() throws Exception {
@@ -163,7 +157,6 @@ public class SqlTimeValueFactoryTest extends CommonAsserts {
 
     @Test
     public void testCreateFromBytes() {
-
         Field f = new Field("test", "test", 33, "UTF-8", MysqlType.VARCHAR, 10);
 
         this.pset.getBooleanProperty(PropertyKey.emptyStringsConvertToZero).setValue(true);
@@ -187,14 +180,7 @@ public class SqlTimeValueFactoryTest extends CommonAsserts {
         assertEquals(Time.valueOf(LocalTime.of(3, 4, 5, 600000000)).toString(),
                 this.vf.createFromBytes("2018-01-02 03:04:05.6".getBytes(), 0, 21, f).toString());
         assertEquals(Time.valueOf(LocalTime.of(3, 4, 5, 600000000)).toString(), this.vf.createFromBytes("03:04:05.6".getBytes(), 0, 10, f).toString());
-
-        assertThrows(DataConversionException.class, "Unsupported conversion from DATE to java.sql.Time", new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-                SqlTimeValueFactoryTest.this.vf.createFromBytes("2018-01-02".getBytes(), 0, 10, f);
-                return null;
-            }
-        });
+        assertEquals(Time.valueOf(LocalTime.of(0, 0)).toString(), this.vf.createFromBytes("2018-01-02".getBytes(), 0, 10, f).toString());
 
         assertThrows(DataConversionException.class, "Cannot convert string '1' to java.sql.Time value", new Callable<Void>() {
             @Override
