@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2021, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2.0, as published by the
@@ -29,9 +29,10 @@
 
 package testsuite.x.internal;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -41,9 +42,9 @@ import java.util.function.Function;
 import java.util.function.Predicate;
 import java.util.stream.Collectors;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import com.mysql.cj.MysqlxSession;
 import com.mysql.cj.conf.DefaultPropertySet;
@@ -68,14 +69,14 @@ import com.mysql.cj.xdevapi.UpdateResultBuilder;
 public class MysqlxSessionTest extends InternalXBaseTestCase {
     private MysqlxSession session;
 
-    @Before
+    @BeforeEach
     public void setupTestSession() {
         if (this.isSetForXTests) {
             this.session = createTestSession();
         }
     }
 
-    @After
+    @AfterEach
     public void destroyTestSession() {
         if (this.isSetForXTests && this.session != null) {
             this.session.quit();
@@ -84,9 +85,8 @@ public class MysqlxSessionTest extends InternalXBaseTestCase {
 
     @Test
     public void testCreateDropCollection() {
-        if (!this.isSetForXTests) {
-            return;
-        }
+        assumeTrue(this.isSetForXTests);
+
         String collName = "toBeCreatedAndDropped";
         XMessageBuilder builder = (XMessageBuilder) this.session.<XMessage>getMessageBuilder();
         try {
@@ -113,9 +113,8 @@ public class MysqlxSessionTest extends InternalXBaseTestCase {
 
     @Test
     public void testGetObjects() {
-        if (!this.isSetForXTests) {
-            return;
-        }
+        assumeTrue(this.isSetForXTests);
+
         XMessageBuilder builder = (XMessageBuilder) this.session.<XMessage>getMessageBuilder();
         ValueFactory<String> svf = new StringValueFactory(new DefaultPropertySet());
         String collName = "test_get_objects";
@@ -145,9 +144,8 @@ public class MysqlxSessionTest extends InternalXBaseTestCase {
 
     @Test
     public void testInterleavedResults() {
-        if (!this.isSetForXTests) {
-            return;
-        }
+        assumeTrue(this.isSetForXTests);
+
         XMessageBuilder builder = (XMessageBuilder) this.session.<XMessage>getMessageBuilder();
         String collName = "testInterleavedResults";
         try {
@@ -203,9 +201,8 @@ public class MysqlxSessionTest extends InternalXBaseTestCase {
 
     @Test
     public void testGenericQuery() {
-        if (!this.isSetForXTests) {
-            return;
-        }
+        assumeTrue(this.isSetForXTests);
+
         XMessageBuilder builder = (XMessageBuilder) this.session.<XMessage>getMessageBuilder();
         List<Integer> ints = this.session.query(builder.buildSqlStatement("select 2 union select 1"), null,
                 r -> r.getValue(0, new IntegerValueFactory(new DefaultPropertySet())), Collectors.toList());
